from setuptools import setup
setup(
    name = 'wumbo',
    version = '1.0.0',
    packages= ['wumbo'],
    description = "Wumbology, the study of Wumbo",
    author = 'Aaron Graubert, but mostly Shankara Anand',
    author_email = 'totallyfakeemail@gmail.com',
    long_description = "Wumbology, the study of Wumbo",
    classifiers = [
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
    ],
)
